@@ -17,15 +17,15 @@
 #' chk_null_or(1, chk_number)
 #' try(chk_null_or("1", chk_number))
 chk_null_or <- function(x, chk, ..., vld, x_name = NULL) {
-  if(!missing(chk)) {
+  if (!missing(chk)) {
     lifecycle::deprecate_soft("0.6.1", "chk_null_or(chk)", "chk_null_or(vld)")
   }
   if (is.null(x)) {
     return(invisible(x))
   }
-  if(missing(vld)) {
+  if (missing(vld)) {
     try <- try_chk(chk(x, ...))
-    if(is.null(try)) {
+    if (is.null(try)) {
       return(invisible(x))
     }
 
@@ -37,7 +37,9 @@ chk_null_or <- function(x, chk, ..., vld, x_name = NULL) {
     msg <- sub("[.]$", " or NULL.", msg)
     abort_chk(msg, x = x)
   }
-  if(vld(x, ...)) return(invisible(x))
+  if (vld(x, ...)) {
+    return(invisible(x))
+  }
 
   if (is.null(x_name)) {
     x_name <- deparse_backtick_chk(substitute(x))
