@@ -1,5 +1,3 @@
-context("chk-atomic")
-
 test_that("vld_atomic", {
   expect_true(vld_atomic(1))
   expect_true(vld_atomic(matrix(1:3)))
@@ -9,7 +7,7 @@ test_that("vld_atomic", {
 })
 
 test_that("chk_atomic", {
-  expect_null(chk_atomic(1))
+  expect_identical(chk_atomic(1), 1)
   expect_invisible(chk_atomic(1))
   expect_chk_error(chk_atomic(list(1)), "^`list[(]1[)]` must be atomic[.]$")
   expect_chk_error(chk_atomic(list(1), x_name = 1), "^1 must be atomic[.]$")
